[pypy-commit] pypy gc-del: Another __del__

arigo noreply at buildbot.pypy.org
Fri Apr 26 15:48:13 CEST 2013


Author: Armin Rigo <arigo at tunes.org>
Branch: gc-del
Changeset: r63649:a046776e4e7d
Date: 2013-04-26 15:50 +0200
http://bitbucket.org/pypy/pypy/changeset/a046776e4e7d/

Log:	Another __del__

diff --git a/pypy/module/_io/interp_bufferedio.py b/pypy/module/_io/interp_bufferedio.py
--- a/pypy/module/_io/interp_bufferedio.py
+++ b/pypy/module/_io/interp_bufferedio.py
@@ -957,9 +957,9 @@
             self.w_writer = None
             raise
 
-    def __del__(self):
+    def invoke_finalizer(self):
         self.clear_all_weakrefs()
         # Don't call the base __del__: do not close the files!
 
     # forward to reader
     for method in ['read', 'peek', 'read1', 'readinto', 'readable']:
@@ -957,9 +957,9 @@
         self.clear_all_weakrefs()
-        # Don't call the base __del__: do not close the files!
+        # Don't call the base invoke_finalizer(): do not close the files!
 
     # forward to reader


More information about the pypy-commit mailing list